<?php

/**
 * @file
 *
 */

/**
 * Extends LuceneapiIndexer.
 */
class LuceneapiNoIndexer extends LuceneapiIndexer {

  /**
   * Returns node ID's that are queued to be indexed.
   */
  public function getQueue(LuceneapiIndex $index, $length = 0) {
    return array();
  }

  /**
   * Resets the index queue.
   */
  public function resetQueue(LuceneapiIndex $index) {
    return TRUE;
  }

  /**
   * Invoked just prior to building the item for indexing.
   */
  public function preBuild($item, LuceneapiIndex $index) {
    return TRUE;
  }

  /**
   * Processes an item for indexing.  In this case we are loading the node and
   * building the search display.
   *
   * @param $item
   *   A mixed value containing the item being indexed.
   * @param $index
   *   A LuceneapiIndex object.
   * @return
   *   A mixed value containing the item built for indexing.
   */
  public function buildItem($item, LuceneapiIndex $index) {
    return array();
  }

  /**
   * Process an item display in search results.
   *
   * @param $hit
   *   A LuceneapiHit
   * @param $index
   *   A LuceneapiIndex object.
   * @return
   *   A mixed value containing the item built for indexing.
   */
  public function buildResult(LuceneapiHit $hit, LuceneapiIndex $index) {

    // Fakes the user object.
    $account = new stdClass();
    $account->uid = $hit->uid;
    $account->name = $hit->name;

    // @todo Break Zend Framework dependency here.
    if (function_exists('luceneapi_zf_highlight_matches')) {
      $snippet = luceneapi_zf_highlight_matches($hit->body, $index);
    }
    else {
      $snippet = truncate_utf8($hit->body, 255);
    }

    // Builds and returns the result.
    $result = array(
      'link' => $hit->link,
      'title' => $hit->title,
      'score' => $hit->score,
      'snippet' => $snippet,
    );

    return $result;
  }

}
